pub struct Ch1statClrErrorCode(/* private fields */);Implementations
Sourceimpl Ch1statClrErrorCode
impl Ch1statClrErrorCode
Sourcepub const NEXT_CHAIN_IS_0: Self
pub const NEXT_CHAIN_IS_0: Self
Error is signalled because the next pointer is 0x00000000.
Sourcepub const NO_CHAIN: Self
pub const NO_CHAIN: Self
Error is signalled because the semaphore is of a non-zero value and neither of the chain bits is set.
Sourcepub const CONTEXT_ERROR: Self
pub const CONTEXT_ERROR: Self
Error is signalled because an error was reported when reading/writing the context buffer.
Sourcepub const PAYLOAD_ERROR: Self
pub const PAYLOAD_ERROR: Self
Error is signalled because an error was reported when reading/writing the payload.
Sourcepub const INVALID_MODE: Self
pub const INVALID_MODE: Self
Error is signalled because the control packet specifies an invalid mode select (for example, blit + hash).